@@ -18,21 +18,20 @@ let nbChangedFiles = 0;
 // to track the number of already computed files diffs
 let nbDiffsComputed = 0;
 
-// the no newline at end of file marker from Github
-let noNewLineMarker = '<span class="no-nl-marker" title="No newline at end of file">' +
-                        '<svg aria-hidden="true" height="16" version="1.1" viewBox="0 0 16 16" width="16">' +
-                          '<path fill-rule="evenodd" d="M16 5v3c0 .55-.45 1-1 1h-3v2L9 8l3-3v2h2V5h2zM8 8c0 2.2-1.8 4-4 4s-4-1.8-4-4 1.8-4 4-4 4 1.8 4 4zM1.5 9.66L5.66 5.5C5.18 5.19 4.61 5 4 5 2.34 5 1 6.34 1 8c0 .61.19 1.17.5 1.66zM7 8c0-.61-.19-1.17-.5-1.66L2.34 10.5c.48.31 1.05.5 1.66.5 1.66 0 3-1.34 3-3z"></path>' +
-                        '</svg>' +
-                      '</span>';
+const noNewLineMarker =
+  '<span class="no-nl-marker" style="color: red;" title="No newline at end of file">' +
+    '<i class="mdi mdi-rotate-90 mdi-cancel" aria-hidden="true">' +
+    '<i class="mdi mdi-keyboard-return" aria-hidden="true">' +
+  '</span>';
 
 // to track the total number of added lines in files diffs
 let nbAdditions = 0;
 // to track the total number of deleted lines in files diffs
 let nbDeletions = 0;
 // to track the already computed diffs by id
-let computedDiffs = {};
+const computedDiffs = {};
 // map a diff id to its computation url
-let diffsUrls = {};
+const diffsUrls = {};
 // to keep track of diff lines to highlight
 let startLines = null;
 let endLines = null;
@@ -51,11 +50,11 @@ let currentTabName = 'Files';
 
 // to check if a DOM element is in the viewport
 function isInViewport(elt) {
-  let elementTop = $(elt).offset().top;
-  let elementBottom = elementTop + $(elt).outerHeight();
+  const elementTop = $(elt).offset().top;
+  const elementBottom = elementTop + $(elt).outerHeight();
 
-  let viewportTop = $(window).scrollTop();
-  let viewportBottom = viewportTop + $(window).height();
+  const viewportTop = $(window).scrollTop();
+  const viewportBottom = viewportTop + $(window).height();
 
   return elementBottom > viewportTop && elementTop < viewportBottom;
 }
@@ -81,14 +80,14 @@ export function formatDiffLineNumbers(diffId, fromLine, toLine) {
 function parseDiffHunkRangeIfAny(lineText) {
   let baseFromLine, baseToLine;
   if (lineText.startsWith('@@')) {
-    let linesInfoRegExp = new RegExp(/^@@ -(\d+),(\d+) \+(\d+),(\d+) @@$/gm);
-    let linesInfoRegExp2 = new RegExp(/^@@ -(\d+) \+(\d+),(\d+) @@$/gm);
-    let linesInfoRegExp3 = new RegExp(/^@@ -(\d+),(\d+) \+(\d+) @@$/gm);
-    let linesInfoRegExp4 = new RegExp(/^@@ -(\d+) \+(\d+) @@$/gm);
-    let linesInfo = linesInfoRegExp.exec(lineText);
-    let linesInfo2 = linesInfoRegExp2.exec(lineText);
-    let linesInfo3 = linesInfoRegExp3.exec(lineText);
-    let linesInfo4 = linesInfoRegExp4.exec(lineText);
+    const linesInfoRegExp = new RegExp(/^@@ -(\d+),(\d+) \+(\d+),(\d+) @@$/gm);
+    const linesInfoRegExp2 = new RegExp(/^@@ -(\d+) \+(\d+),(\d+) @@$/gm);
+    const linesInfoRegExp3 = new RegExp(/^@@ -(\d+),(\d+) \+(\d+) @@$/gm);
+    const linesInfoRegExp4 = new RegExp(/^@@ -(\d+) \+(\d+) @@$/gm);
+    const linesInfo = linesInfoRegExp.exec(lineText);
+    const linesInfo2 = linesInfoRegExp2.exec(lineText);
+    const linesInfo3 = linesInfoRegExp3.exec(lineText);
+    const linesInfo4 = linesInfoRegExp4.exec(lineText);
     if (linesInfo) {
       baseFromLine = parseInt(linesInfo[1]) - 1;
       baseToLine = parseInt(linesInfo[3]) - 1;
@@ -128,7 +127,7 @@ export function parseDiffLineNumbers(lineNumbersStr, from, to) {
     }
     lines = lines.map(x => toLnInt(x));
   } else {
-    let lineNumber = toLnInt(lineNumbersStr.trim());
+    const lineNumber = toLnInt(lineNumbersStr.trim());
     if (from) {
       lines = [lineNumber, 0];
     } else if (to) {
@@ -170,8 +169,8 @@ export function fragmentToSelectedDiffLines(fragment) {
 
 // function to highlight a single diff line
 function highlightDiffLine(diffId, i) {
-  let line = $(`#${diffId} .hljs-ln-line[data-line-number="${i}"]`);
-  let lineNumbers = $(`#${diffId} .hljs-ln-numbers[data-line-number="${i}"]`);
+  const line = $(`#${diffId} .hljs-ln-line[data-line-number="${i}"]`);
+  const lineNumbers = $(`#${diffId} .hljs-ln-numbers[data-line-number="${i}"]`);
   lineNumbers.css('color', 'black');
   lineNumbers.css('font-weight', 'bold');
   line.css('background-color', lineHighlightColor);
@@ -297,7 +296,7 @@ function highlightDiffLines(diffId, startLines, endLines, unified) {
     }
   }
 
-  let selectedLinesFragment = selectedDiffLinesToFragment(startLines, endLines, unified);
+  const selectedLinesFragment = selectedDiffLinesToFragment(startLines, endLines, unified);
   window.location.hash = `diff_${diffId}+${selectedLinesFragment}`;
   return firstHighlightedLine;
 }
@@ -315,10 +314,10 @@ export function showSplitDiff(diffId) {
 }
 
 // to compute diff and process it for display
-export function computeDiff(diffUrl, diffId) {
+export async function computeDiff(diffUrl, diffId) {
 
   // force diff computation ?
-  let force = diffUrl.indexOf('force=true') !== -1;
+  const force = diffUrl.indexOf('force=true') !== -1;
 
   // it no forced computation and diff already computed, do nothing
   if (!force && computedDiffs.hasOwnProperty(diffId)) {
@@ -341,214 +340,214 @@ export function computeDiff(diffUrl, diffId) {
   $(`#${diffId}-highlightjs`).css('display', 'none');
 
   // request diff computation and process it
-  fetch(diffUrl)
-    .then(response => response.json())
-    .then(data => {
-      // increment number of computed diffs
-      ++nbDiffsComputed;
-      // toggle the 'Compute all diffs' button if all diffs have been computed
-      if (nbDiffsComputed === changes.length) {
-        $('#swh-compute-all-diffs').addClass('active');
-      }
+  const response = await fetch(diffUrl);
+  const data = await response.json();
 
-      // Large diff (> threshold) are not automatically computed,
-      // add a button to force its computation
-      if (data.diff_str.indexOf('Large diff') === 0) {
-        $(`#${diffId}`)[0].innerHTML = data.diff_str +
+  // increment number of computed diffs
+  ++nbDiffsComputed;
+  // toggle the 'Compute all diffs' button if all diffs have been computed
+  if (nbDiffsComputed === changes.length) {
+    $('#swh-compute-all-diffs').addClass('active');
+  }
+
+  // Large diff (> threshold) are not automatically computed,
+  // add a button to force its computation
+  if (data.diff_str.indexOf('Large diff') === 0) {
+    $(`#${diffId}`)[0].innerHTML = data.diff_str +
           `<br/><button class="btn btn-default btn-sm" type="button"
            onclick="swh.revision.computeDiff('${diffUrl}&force=true', '${diffId}')">` +
            'Request diff</button>';
-        setDiffVisible(diffId);
-      } else if (data.diff_str.indexOf('@@') !== 0) {
-        $(`#${diffId}`).text(data.diff_str);
-        setDiffVisible(diffId);
+    setDiffVisible(diffId);
+  } else if (data.diff_str.indexOf('@@') !== 0) {
+    $(`#${diffId}`).text(data.diff_str);
+    setDiffVisible(diffId);
+  } else {
+
+    // prepare code highlighting
+    $(`.${diffId}`).removeClass('plaintext');
+    $(`.${diffId}`).addClass(data.language);
+
+    // set unified diff text
+    $(`#${diffId}`).text(data.diff_str);
+
+    // code highlighting for unified diff
+    $(`#${diffId}`).each((i, elt) => {
+      hljs.highlightElement(elt);
+      hljs.lineNumbersElementSync(elt);
+    });
+
+    // process unified diff lines in order to generate side-by-side diffs text
+    // but also compute line numbers for unified and side-by-side diffs
+    let baseFromLine = '';
+    let baseToLine = '';
+    const fromToLines = [];
+    const fromLines = [];
+    const toLines = [];
+    let maxNumberChars = 0;
+    let diffFromStr = '';
+    let diffToStr = '';
+    let linesOffset = 0;
+
+    $(`#${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
+      const lnText = lnElt.nextSibling.innerText;
+      const linesInfo = parseDiffHunkRangeIfAny(lnText);
+      let fromLine = '';
+      let toLine = '';
+      // parsed lines info from the diff output
+      if (linesInfo) {
+        baseFromLine = linesInfo[0];
+        baseToLine = linesInfo[1];
+        linesOffset = 0;
+        diffFromStr += (lnText + '\n');
+        diffToStr += (lnText + '\n');
+        fromLines.push('');
+        toLines.push('');
+        // line removed in the from file
+      } else if (lnText.length > 0 && lnText[0] === '-') {
+        baseFromLine = baseFromLine + 1;
+        fromLine = baseFromLine.toString();
+        fromLines.push(fromLine);
+        ++nbDeletions;
+        diffFromStr += (lnText + '\n');
+        ++linesOffset;
+        // line added in the to file
+      } else if (lnText.length > 0 && lnText[0] === '+') {
+        baseToLine = baseToLine + 1;
+        toLine = baseToLine.toString();
+        toLines.push(toLine);
+        ++nbAdditions;
+        diffToStr += (lnText + '\n');
+        --linesOffset;
+        // line present in both files
       } else {
-
-        // prepare code highlighting
-        $(`.${diffId}`).removeClass('nohighlight');
-        $(`.${diffId}`).addClass(data.language);
-
-        // set unified diff text
-        $(`#${diffId}`).text(data.diff_str);
-
-        // code highlighting for unified diff
-        $(`#${diffId}`).each((i, elt) => {
-          hljs.highlightElement(elt);
-          hljs.lineNumbersElementSync(elt);
-        });
-
-        // process unified diff lines in order to generate side-by-side diffs text
-        // but also compute line numbers for unified and side-by-side diffs
-        let baseFromLine = '';
-        let baseToLine = '';
-        let fromToLines = [];
-        let fromLines = [];
-        let toLines = [];
-        let maxNumberChars = 0;
-        let diffFromStr = '';
-        let diffToStr = '';
-        let linesOffset = 0;
-
-        $(`#${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
-          let lnText = lnElt.nextSibling.innerText;
-          let linesInfo = parseDiffHunkRangeIfAny(lnText);
-          let fromLine = '';
-          let toLine = '';
-          // parsed lines info from the diff output
-          if (linesInfo) {
-            baseFromLine = linesInfo[0];
-            baseToLine = linesInfo[1];
-            linesOffset = 0;
-            diffFromStr += (lnText + '\n');
-            diffToStr += (lnText + '\n');
-            fromLines.push('');
+        baseFromLine = baseFromLine + 1;
+        baseToLine = baseToLine + 1;
+        fromLine = baseFromLine.toString();
+        toLine = baseToLine.toString();
+        for (let j = 0; j < Math.abs(linesOffset); ++j) {
+          if (linesOffset > 0) {
+            diffToStr += '\n';
             toLines.push('');
-          // line removed in the from file
-          } else if (lnText.length > 0 && lnText[0] === '-') {
-            baseFromLine = baseFromLine + 1;
-            fromLine = baseFromLine.toString();
-            fromLines.push(fromLine);
-            ++nbDeletions;
-            diffFromStr += (lnText + '\n');
-            ++linesOffset;
-          // line added in the to file
-          } else if (lnText.length > 0 && lnText[0] === '+') {
-            baseToLine = baseToLine + 1;
-            toLine = baseToLine.toString();
-            toLines.push(toLine);
-            ++nbAdditions;
-            diffToStr += (lnText + '\n');
-            --linesOffset;
-          // line present in both files
           } else {
-            baseFromLine = baseFromLine + 1;
-            baseToLine = baseToLine + 1;
-            fromLine = baseFromLine.toString();
-            toLine = baseToLine.toString();
-            for (let j = 0; j < Math.abs(linesOffset); ++j) {
-              if (linesOffset > 0) {
-                diffToStr += '\n';
-                toLines.push('');
-              } else {
-                diffFromStr += '\n';
-                fromLines.push('');
-              }
-            }
-            linesOffset = 0;
-            diffFromStr += (lnText + '\n');
-            diffToStr += (lnText + '\n');
-            toLines.push(toLine);
-            fromLines.push(fromLine);
+            diffFromStr += '\n';
+            fromLines.push('');
           }
-          if (!baseFromLine) {
-            fromLine = '';
-          }
-          if (!baseToLine) {
-            toLine = '';
-          }
-          fromToLines[i] = [fromLine, toLine];
-          maxNumberChars = Math.max(maxNumberChars, fromLine.length);
-          maxNumberChars = Math.max(maxNumberChars, toLine.length);
-        });
-
-        diffMaxNumberChars[diffId] = maxNumberChars;
-
-        // set side-by-side diffs text
-        $(`#${diffId}-from`).text(diffFromStr);
-        $(`#${diffId}-to`).text(diffToStr);
-
-        // code highlighting for side-by-side diffs
-        $(`#${diffId}-from, #${diffId}-to`).each((i, elt) => {
-          hljs.highlightElement(elt);
-          hljs.lineNumbersElementSync(elt);
-        });
-
-        // diff highlighting for added/removed lines on top of code highlighting
-        $(`.${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
-          let lnText = lnElt.nextSibling.innerText;
-          if (lnText.startsWith('@@')) {
-            $(lnElt).parent().addClass('swh-diff-lines-info');
-            let linesInfoText = $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').text();
-            $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').children().remove();
-            $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').text('');
-            $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').append(`<span class="hljs-meta">${linesInfoText}</span>`);
-          } else if (lnText.length > 0 && lnText[0] === '-') {
-            $(lnElt).parent().addClass('swh-diff-removed-line');
-          } else if (lnText.length > 0 && lnText[0] === '+') {
-            $(lnElt).parent().addClass('swh-diff-added-line');
-          }
-        });
-
-        // set line numbers for unified diff
-        $(`#${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
-          const lineNumbers = formatDiffLineNumbers(diffId, fromToLines[i][0], fromToLines[i][1]);
-          setLineNumbers(lnElt, lineNumbers);
-        });
-
-        // set line numbers for the from side-by-side diff
-        $(`#${diffId}-from .hljs-ln-numbers`).each((i, lnElt) => {
-          setLineNumbers(lnElt, fromLines[i]);
-        });
-
-        // set line numbers for the to side-by-side diff
-        $(`#${diffId}-to .hljs-ln-numbers`).each((i, lnElt) => {
-          setLineNumbers(lnElt, toLines[i]);
-        });
-
-        // last processing:
-        //  - remove the '+' and '-' at the beginning of the diff lines
-        //    from code highlighting
-        //  - add the "no new line at end of file marker" if needed
-        $(`.${diffId} .hljs-ln-code`).each((i, lnElt) => {
-          if (lnElt.firstChild) {
-            if (lnElt.firstChild.nodeName !== '#text') {
-              let lineText = lnElt.firstChild.innerHTML;
-              if (lineText[0] === '-' || lineText[0] === '+') {
-                lnElt.firstChild.innerHTML = lineText.substr(1);
-                let newTextNode = document.createTextNode(lineText[0]);
-                $(lnElt).prepend(newTextNode);
-              }
-            }
-            $(lnElt).contents().filter((i, elt) => {
-              return elt.nodeType === 3; // Node.TEXT_NODE
-            }).each((i, textNode) => {
-              let swhNoNewLineMarker = '[swh-no-nl-marker]';
-              if (textNode.textContent.indexOf(swhNoNewLineMarker) !== -1) {
-                textNode.textContent = textNode.textContent.replace(swhNoNewLineMarker, '');
-                $(lnElt).append($(noNewLineMarker));
-              }
-            });
-          }
-        });
-
-        // hide the diff mode switch button in case of not generated diffs
-        if (data.diff_str.indexOf('Diffs are not generated for non textual content') !== 0) {
-          $(`#diff_${diffId} .diff-styles`).css('visibility', 'visible');
         }
+        linesOffset = 0;
+        diffFromStr += (lnText + '\n');
+        diffToStr += (lnText + '\n');
+        toLines.push(toLine);
+        fromLines.push(fromLine);
+      }
+      if (!baseFromLine) {
+        fromLine = '';
+      }
+      if (!baseToLine) {
+        toLine = '';
+      }
+      fromToLines[i] = [fromLine, toLine];
+      maxNumberChars = Math.max(maxNumberChars, fromLine.length);
+      maxNumberChars = Math.max(maxNumberChars, toLine.length);
+    });
 
-        setDiffVisible(diffId);
+    diffMaxNumberChars[diffId] = maxNumberChars;
 
-        // highlight diff lines if provided in URL fragment
-        if (selectedDiffLinesInfo &&
-              selectedDiffLinesInfo.diffPanelId.indexOf(diffId) !== -1) {
-          if (!selectedDiffLinesInfo.unified) {
-            showSplitDiff(diffId);
-          }
-          const firstHighlightedLine = highlightDiffLines(
-            diffId, selectedDiffLinesInfo.startLines,
-            selectedDiffLinesInfo.endLines, selectedDiffLinesInfo.unified);
+    // set side-by-side diffs text
+    $(`#${diffId}-from`).text(diffFromStr);
+    $(`#${diffId}-to`).text(diffToStr);
 
-          $('html, body').animate(
-            {
-              scrollTop: firstHighlightedLine.offset().top - 50
-            },
-            {
-              duration: 500
-            }
-          );
-        }
+    // code highlighting for side-by-side diffs
+    $(`#${diffId}-from, #${diffId}-to`).each((i, elt) => {
+      hljs.highlightElement(elt);
+      hljs.lineNumbersElementSync(elt);
+    });
+
+    // diff highlighting for added/removed lines on top of code highlighting
+    $(`.${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
+      const lnText = lnElt.nextSibling.innerText;
+      if (lnText.startsWith('@@')) {
+        $(lnElt).parent().addClass('swh-diff-lines-info');
+        const linesInfoText = $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').text();
+        $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').children().remove();
+        $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').text('');
+        $(lnElt).parent().find('.hljs-ln-code .hljs-ln-line').append(`<span class="hljs-meta">${linesInfoText}</span>`);
+      } else if (lnText.length > 0 && lnText[0] === '-') {
+        $(lnElt).parent().addClass('swh-diff-removed-line');
+      } else if (lnText.length > 0 && lnText[0] === '+') {
+        $(lnElt).parent().addClass('swh-diff-added-line');
       }
     });
+
+    // set line numbers for unified diff
+    $(`#${diffId} .hljs-ln-numbers`).each((i, lnElt) => {
+      const lineNumbers = formatDiffLineNumbers(diffId, fromToLines[i][0], fromToLines[i][1]);
+      setLineNumbers(lnElt, lineNumbers);
+    });
+
+    // set line numbers for the from side-by-side diff
+    $(`#${diffId}-from .hljs-ln-numbers`).each((i, lnElt) => {
+      setLineNumbers(lnElt, fromLines[i]);
+    });
+
+    // set line numbers for the to side-by-side diff
+    $(`#${diffId}-to .hljs-ln-numbers`).each((i, lnElt) => {
+      setLineNumbers(lnElt, toLines[i]);
+    });
+
+    // last processing:
+    //  - remove the '+' and '-' at the beginning of the diff lines
+    //    from code highlighting
+    //  - add the "no new line at end of file marker" if needed
+    $(`.${diffId} .hljs-ln-code`).each((i, lnElt) => {
+      if (lnElt.firstChild) {
+        if (lnElt.firstChild.nodeName !== '#text') {
+          const lineText = lnElt.firstChild.innerHTML;
+          if (lineText[0] === '-' || lineText[0] === '+') {
+            lnElt.firstChild.innerHTML = lineText.substr(1);
+            const newTextNode = document.createTextNode(lineText[0]);
+            $(lnElt).prepend(newTextNode);
+          }
+        }
+        $(lnElt).contents().filter((i, elt) => {
+          return elt.nodeType === 3; // Node.TEXT_NODE
+        }).each((i, textNode) => {
+          const swhNoNewLineMarker = '[swh-no-nl-marker]';
+          if (textNode.textContent.indexOf(swhNoNewLineMarker) !== -1) {
+            textNode.textContent = textNode.textContent.replace(swhNoNewLineMarker, '');
+            $(lnElt).append($(noNewLineMarker));
+          }
+        });
+      }
+    });
+
+    // hide the diff mode switch button in case of not generated diffs
+    if (data.diff_str.indexOf('Diffs are not generated for non textual content') !== 0) {
+      $(`#diff_${diffId} .diff-styles`).css('visibility', 'visible');
+    }
+
+    setDiffVisible(diffId);
+
+    // highlight diff lines if provided in URL fragment
+    if (selectedDiffLinesInfo &&
+              selectedDiffLinesInfo.diffPanelId.indexOf(diffId) !== -1) {
+      if (!selectedDiffLinesInfo.unified) {
+        showSplitDiff(diffId);
+      }
+      const firstHighlightedLine = highlightDiffLines(
+        diffId, selectedDiffLinesInfo.startLines,
+        selectedDiffLinesInfo.endLines, selectedDiffLinesInfo.unified);
+
+      $('html, body').animate(
+        {
+          scrollTop: firstHighlightedLine.offset().top - 50
+        },
+        {
+          duration: 500
+        }
+      );
+    }
+  }
+
 }
 
 function setDiffVisible(diffId) {
@@ -570,7 +569,7 @@ function setDiffVisible(diffId) {
 function computeVisibleDiffs() {
   $('.swh-file-diff-panel').each((i, elt) => {
     if (isInViewport(elt)) {
-      let diffId = elt.id.replace('diff_', '');
+      const diffId = elt.id.replace('diff_', '');
       computeDiff(diffsUrls[diffId], diffId);
     }
   });
@@ -591,14 +590,14 @@ function genDiffPanel(diffData) {
 // setup waypoints to request diffs computation on the fly while scrolling
 function setupWaypoints() {
   for (let i = 0; i < changes.length; ++i) {
-    let diffData = changes[i];
+    const diffData = changes[i];
 
     // create a waypoint that will trigger diff computation when
     // the top of the diff panel hits the bottom of the viewport
     $(`#diff_${diffData.id}`).waypoint({
       handler: function() {
         if (isInViewport(this.element)) {
-          let diffId = this.element.id.replace('diff_', '');
+          const diffId = this.element.id.replace('diff_', '');
           computeDiff(diffsUrls[diffId], diffId);
           this.destroy();
         }
@@ -611,7 +610,7 @@ function setupWaypoints() {
     $(`#diff_${diffData.id}`).waypoint({
       handler: function() {
         if (isInViewport(this.element)) {
-          let diffId = this.element.id.replace('diff_', '');
+          const diffId = this.element.id.replace('diff_', '');
           computeDiff(diffsUrls[diffId], diffId);
           this.destroy();
         }
@@ -651,7 +650,7 @@ function scrollToDiffPanel(diffPanelId, setHash = true) {
 // callback when the user clicks on the 'Compute all diffs' button
 export function computeAllDiffs(event) {
   $(event.currentTarget).addClass('active');
-  for (let diffId in diffsUrls) {
+  for (const diffId in diffsUrls) {
     if (diffsUrls.hasOwnProperty(diffId)) {
       computeDiff(diffsUrls[diffId], diffId);
     }
@@ -664,7 +663,7 @@ export async function initRevisionDiff(revisionMessageBody, diffRevisionUrl) {
   await import(/* webpackChunkName: "highlightjs" */ 'utils/highlightjs');
 
   // callback when the 'Changes' tab is activated
-  $(document).on('shown.bs.tab', 'a[data-toggle="tab"]', e => {
+  $(document).on('shown.bs.tab', 'a[data-toggle="tab"]', async e => {
     currentTabName = e.currentTarget.text.trim();
     if (currentTabName === 'Changes') {
       window.location.hash = changesUrlFragment;
@@ -677,43 +676,42 @@ export async function initRevisionDiff(revisionMessageBody, diffRevisionUrl) {
       // request computation of revision file changes list
       // when navigating to the 'Changes' tab and add diff panels
       // to the DOM when receiving the result
-      fetch(diffRevisionUrl)
-        .then(response => response.json())
-        .then(data => {
-          changes = data.changes;
-          nbChangedFiles = data.total_nb_changes;
-          let changedFilesText = `${nbChangedFiles} changed file`;
-          if (nbChangedFiles !== 1) {
-            changedFilesText += 's';
-          }
-          $('#swh-revision-changed-files').text(changedFilesText);
-          $('#swh-total-nb-diffs').text(changes.length);
-          $('#swh-revision-changes-list pre')[0].innerHTML = data.changes_msg;
+      const response = await fetch(diffRevisionUrl);
+      const data = await response.json();
 
-          $('#swh-revision-changes-loading').css('display', 'none');
-          $('#swh-revision-changes-list pre').css('display', 'block');
-          $('#swh-compute-all-diffs').css('visibility', 'visible');
-          $('#swh-revision-changes-list').removeClass('in');
+      changes = data.changes;
+      nbChangedFiles = data.total_nb_changes;
+      let changedFilesText = `${nbChangedFiles} changed file`;
+      if (nbChangedFiles !== 1) {
+        changedFilesText += 's';
+      }
+      $('#swh-revision-changed-files').text(changedFilesText);
+      $('#swh-total-nb-diffs').text(changes.length);
+      $('#swh-revision-changes-list pre')[0].innerHTML = data.changes_msg;
 
-          if (nbChangedFiles > changes.length) {
-            $('#swh-too-large-revision-diff').css('display', 'block');
-            $('#swh-nb-loaded-diffs').text(changes.length);
-          }
+      $('#swh-revision-changes-loading').css('display', 'none');
+      $('#swh-revision-changes-list pre').css('display', 'block');
+      $('#swh-compute-all-diffs').css('visibility', 'visible');
+      $('#swh-revision-changes-list').removeClass('in');
 
-          for (let i = 0; i < changes.length; ++i) {
-            let diffData = changes[i];
-            diffsUrls[diffData.id] = diffData.diff_url;
-            $('#swh-revision-diffs').append(genDiffPanel(diffData));
-          }
+      if (nbChangedFiles > changes.length) {
+        $('#swh-too-large-revision-diff').css('display', 'block');
+        $('#swh-nb-loaded-diffs').text(changes.length);
+      }
 
-          setupWaypoints();
-          computeVisibleDiffs();
+      for (let i = 0; i < changes.length; ++i) {
+        const diffData = changes[i];
+        diffsUrls[diffData.id] = diffData.diff_url;
+        $('#swh-revision-diffs').append(genDiffPanel(diffData));
+      }
 
-          if (selectedDiffLinesInfo) {
-            scrollToDiffPanel(selectedDiffLinesInfo.diffPanelId, false);
-          }
+      setupWaypoints();
+      computeVisibleDiffs();
+
+      if (selectedDiffLinesInfo) {
+        scrollToDiffPanel(selectedDiffLinesInfo.diffPanelId, false);
+      }
 
-        });
     } else if (currentTabName === 'Files') {
       removeUrlFragment();
       $('#readme-panel').css('display', 'block');
@@ -730,7 +728,7 @@ export async function initRevisionDiff(revisionMessageBody, diffRevisionUrl) {
 
     // callback when the user requests to scroll on a specific diff or back to top
     $('#swh-revision-changes-list a[href^="#"], #back-to-top a[href^="#"]').click(e => {
-      let href = $.attr(e.currentTarget, 'href');
+      const href = $.attr(e.currentTarget, 'href');
       scrollToDiffPanel(href);
       return false;
     });
