@@ -1,17 +1,35 @@
 /**
- * Copyright (C) 2018-2021  The Software Heritage developers
+ * Copyright (C) 2018-2022  The Software Heritage developers
  * See the AUTHORS file at the top-level directory of this distribution
  * License: GNU Affero General Public License version 3, or any later version
  * See top-level LICENSE file for more information
  */
 
-function genSwhLink(data, type) {
-  if (type === 'display') {
-    if (data && data.startsWith('swh')) {
-      const browseUrl = Urls.browse_swhid(data);
-      const formattedSWHID = data.replace(/;/g, ';<br/>');
-      return `<a href="${browseUrl}">${formattedSWHID}</a>`;
+import {getHumanReadableDate} from 'utils/functions';
+
+function genSwhLink(data, type, linkText = '') {
+  if (type === 'display' && data && data.startsWith('swh')) {
+    const browseUrl = Urls.browse_swhid(data);
+    const formattedSWHID = data.replace(/;/g, ';<br/>');
+    if (!linkText) {
+      linkText = formattedSWHID;
     }
+    return `<a href="${browseUrl}">${linkText}</a>`;
+  }
+  return data;
+}
+
+function genLink(data, type, openInNewTab = false, linkText = '') {
+  if (type === 'display' && data) {
+    const sData = encodeURI(data);
+    if (!linkText) {
+      linkText = sData;
+    }
+    let attrs = '';
+    if (openInNewTab) {
+      attrs = 'target="_blank" rel="noopener noreferrer"';
+    }
+    return `<a href="${sData}" ${attrs}>${linkText}</a>`;
   }
   return data;
 }
@@ -55,40 +73,49 @@ export function initDepositAdmin(username, isStaff) {
             name: 'id'
           },
           {
-            data: 'swhid_context',
-            name: 'swhid_context',
+            data: 'type',
+            name: 'type'
+          },
+          {
+            data: 'uri',
+            name: 'uri',
             render: (data, type, row) => {
-              if (data && type === 'display') {
-                const originPattern = ';origin=';
-                const originPatternIdx = data.indexOf(originPattern);
-                if (originPatternIdx !== -1) {
-                  let originUrl = data.slice(originPatternIdx + originPattern.length);
-                  const nextSepPattern = ';';
-                  const nextSepPatternIdx = originUrl.indexOf(nextSepPattern);
-                  if (nextSepPatternIdx !== -1) { /* Remove extra context */
-                    originUrl = originUrl.slice(0, nextSepPatternIdx);
-                  }
-                  return `<a href="${originUrl}">${originUrl}</a>`;
-                }
+              const sanitizedURL = $.fn.dataTable.render.text().display(data);
+              let swhLink = '';
+              let originLink = '';
+              if (row.swhid_context && data) {
+                swhLink = genSwhLink(row.swhid_context, type, sanitizedURL);
+              } else if (data) {
+                swhLink = sanitizedURL;
               }
-              return data;
+              if (data) {
+                originLink = genLink(sanitizedURL, type, true,
+                                     '<i class="mdi mdi-open-in-new" aria-hidden="true"></i>');
+              }
+              return swhLink + '&nbsp;' + originLink;
             }
           },
           {
             data: 'reception_date',
             name: 'reception_date',
-            render: (data, type, row) => {
-              if (type === 'display') {
-                const date = new Date(data);
-                return date.toLocaleString();
-              }
-              return data;
-            }
+            render: getHumanReadableDate
           },
           {
             data: 'status',
             name: 'status'
           },
+          {
+            data: 'raw_metadata',
+            name: 'raw_metadata',
+            render: (data, type, row) => {
+              if (type === 'display') {
+                if (row.raw_metadata) {
+                  return `<button class="btn btn-default metadata">display</button>`;
+                }
+              }
+              return data;
+            }
+          },
           {
             data: 'status_detail',
             name: 'status_detail',
@@ -144,10 +171,23 @@ export function initDepositAdmin(username, isStaff) {
     </div>
   </div>
 `);
+
+    // Show a modal when the "metadata" button is clicked
+    $('#swh-admin-deposit-list tbody').on('click', 'tr button.metadata', function() {
+      var row = depositsTable.row(this.parentNode.parentNode).data();
+      var metadata = row.raw_metadata;
+      var escapedMetadata = $('<div/>').text(metadata).html();
+      swh.webapp.showModalHtml(`Metadata of deposit ${row.id}`,
+                               `<pre style="max-height: 75vh;"><code class="xml">${escapedMetadata}</code></pre>`,
+                               '90%');
+      swh.webapp.highlightCode();
+    });
+
     // Adding exclusion pattern update behavior, when typing, update search
     $('#swh-admin-deposit-list-exclude-filter').keyup(function() {
       depositsTable.draw();
     });
+
     // at last draw the table
     depositsTable.draw();
   });
