@@ -1,14 +1,15 @@
 /**
- * Copyright (C) 2018-2021  The Software Heritage developers
+ * Copyright (C) 2018-2022  The Software Heritage developers
  * See the AUTHORS file at the top-level directory of this distribution
  * License: GNU Affero General Public License version 3, or any later version
  * See top-level LICENSE file for more information
  */
 
-import {csrfPost, handleFetchError, isGitRepoUrl, htmlAlert, removeUrlFragment,
-        getCanonicalOriginURL} from 'utils/functions';
+import {csrfPost, handleFetchError, isGitRepoUrl, htmlAlert,
+        getCanonicalOriginURL, getHumanReadableDate} from 'utils/functions';
 import {swhSpinnerSrc} from 'utils/constants';
 import artifactFormRowTemplate from './artifact-form-row.ejs';
+import userRequestsFilterCheckboxFn from 'utils/requests-filter-checkbox.ejs';
 
 let saveRequestsTable;
 
@@ -103,15 +104,11 @@ export function deleteArtifactFormRow(event) {
   $(event.target).closest('.swh-save-origin-artifact-form').remove();
 }
 
-const userRequestsFilterCheckbox = `
-<div class="custom-control custom-checkbox swhid-option">
-  <input class="custom-control-input" value="option-user-requests-filter" type="checkbox"
-         id="swh-save-requests-user-filter">
-  <label class="custom-control-label font-weight-normal" for="swh-save-requests-user-filter">
-    show only your own requests
-  </label>
-</div>
-`;
+const saveRequestCheckboxId = 'swh-save-requests-user-filter';
+const userRequestsFilterCheckbox = userRequestsFilterCheckboxFn({
+  'inputId': saveRequestCheckboxId,
+  'checked': false // no filtering by default on that view
+});
 
 export function initOriginSave() {
 
@@ -136,7 +133,7 @@ export function initOriginSave() {
         ajax: {
           url: Urls.origin_save_requests_list('all'),
           data: (d) => {
-            if (swh.webapp.isUserLoggedIn() && $('#swh-save-requests-user-filter').prop('checked')) {
+            if (swh.webapp.isUserLoggedIn() && $(`#${saveRequestCheckboxId}`).prop('checked')) {
               d.user_requests_only = '1';
             }
           }
@@ -151,7 +148,7 @@ export function initOriginSave() {
         fnInitComplete: function() {
           if (swh.webapp.isUserLoggedIn()) {
             $('div.user-requests-filter').html(userRequestsFilterCheckbox);
-            $('#swh-save-requests-user-filter').on('change', () => {
+            $(`#${saveRequestCheckboxId}`).on('change', () => {
               saveRequestsTable.draw();
             });
           }
@@ -160,13 +157,7 @@ export function initOriginSave() {
           {
             data: 'save_request_date',
             name: 'request_date',
-            render: (data, type, row) => {
-              if (type === 'display') {
-                const date = new Date(data);
-                return date.toLocaleString();
-              }
-              return data;
-            }
+            render: getHumanReadableDate
           },
           {
             data: 'visit_type',
@@ -180,11 +171,16 @@ export function initOriginSave() {
                 let html = '';
                 const sanitizedURL = $.fn.dataTable.render.text().display(data);
                 if (row.save_task_status === 'succeeded') {
-                  let browseOriginUrl = `${Urls.browse_origin()}?origin_url=${encodeURIComponent(sanitizedURL)}`;
-                  if (row.visit_date) {
-                    browseOriginUrl += `&amp;timestamp=${encodeURIComponent(row.visit_date)}`;
+                  if (row.visit_status === 'full' || row.visit_status === 'partial') {
+                    let browseOriginUrl = `${Urls.browse_origin()}?origin_url=${encodeURIComponent(sanitizedURL)}`;
+                    if (row.visit_date) {
+                      browseOriginUrl += `&amp;timestamp=${encodeURIComponent(row.visit_date)}`;
+                    }
+                    html += `<a href="${browseOriginUrl}">${sanitizedURL}</a>`;
+                  } else {
+                    const tooltip = 'origin was successfully loaded, waiting for data to be available in database';
+                    html += `<span title="${tooltip}">${sanitizedURL}</span>`;
                   }
-                  html += `<a href="${browseOriginUrl}">${sanitizedURL}</a>`;
                 } else {
                   html += sanitizedURL;
                 }
@@ -206,10 +202,11 @@ export function initOriginSave() {
           {
             name: 'info',
             render: (data, type, row) => {
-              if (row.save_task_status === 'succeeded' || row.save_task_status === 'failed') {
-                return `<i class="mdi mdi-information-outline swh-save-request-info" ` +
-                       'aria-hidden="true" style="cursor: pointer"' +
-                       `onclick="swh.save.displaySaveRequestInfo(event, ${row.id})"></i>`;
+              if (row.save_task_status === 'succeeded' || row.save_task_status === 'failed' ||
+                  row.note != null) {
+                return `<i class="mdi mdi-information-outline swh-save-request-info"
+                           aria-hidden="true" style="cursor: pointer"
+                           onclick="swh.save.displaySaveRequestInfo(event, ${row.id})"></i>`;
               } else {
                 return '';
               }
@@ -243,15 +240,12 @@ export function initOriginSave() {
 
     swh.webapp.addJumpToPagePopoverToDataTable(saveRequestsTable);
 
-    $('#swh-origin-save-requests-list-tab').on('shown.bs.tab', () => {
+    if (window.location.pathname === Urls.origin_save() && window.location.hash === '#requests') {
+      // Keep old URLs to the save list working
+      window.location = Urls.origin_save_list();
+    } else if ($('#swh-origin-save-requests')) {
       saveRequestsTable.draw();
-      window.location.hash = '#requests';
-    });
-
-    $('#swh-origin-save-request-help-tab').on('shown.bs.tab', () => {
-      removeUrlFragment();
-      $('.swh-save-request-info').popover('dispose');
-    });
+    }
 
     const saveRequestAcceptedAlert = htmlAlert(
       'success',
@@ -334,6 +328,8 @@ export function initOriginSave() {
         const val = $(this).val();
         if (val && originUrl.includes(val)) {
           $(this).prop('selected', true);
+          // origin URL input need to be validated once new visit type set
+          validateSaveOriginUrl($('#swh-input-origin-url')[0]);
         }
       });
     });
@@ -342,6 +338,14 @@ export function initOriginSave() {
       $('.nav-tabs a[href="#swh-origin-save-requests-list"]').tab('show');
     }
 
+    $(window).on('hashchange', () => {
+      if (window.location.hash === '#requests') {
+        $('.nav-tabs a[href="#swh-origin-save-requests-list"]').tab('show');
+      } else {
+        $('.nav-tabs a[href="#swh-origin-save-requests-create"]').tab('show');
+      }
+    });
+
   });
 
 }
@@ -358,33 +362,14 @@ export function validateSaveOriginUrl(input) {
   }
 
   if (validUrl) {
-    const allowedProtocols = ['http:', 'https:', 'svn:', 'git:'];
+    const allowedProtocols = ['http:', 'https:', 'svn:', 'git:', 'rsync:', 'pserver:', 'ssh:', 'bzr:'];
     validUrl = (
       allowedProtocols.find(protocol => protocol === originUrl.protocol) !== undefined
     );
   }
 
   if (validUrl && originType === 'git') {
-    // additional checks for well known code hosting providers
-    switch (originUrl.hostname) {
-      case 'github.com':
-        validUrl = isGitRepoUrl(originUrl);
-        break;
-
-      case 'git.code.sf.net':
-        validUrl = isGitRepoUrl(originUrl, '/p/');
-        break;
-
-      case 'bitbucket.org':
-        validUrl = isGitRepoUrl(originUrl);
-        break;
-
-      default:
-        if (originUrl.hostname.startsWith('gitlab.')) {
-          validUrl = isGitRepoUrl(originUrl);
-        }
-        break;
-    }
+    validUrl = isGitRepoUrl(originUrl);
   }
 
   if (validUrl) {
@@ -500,6 +485,9 @@ export async function displaySaveRequestInfo(event, saveRequestId) {
   let content;
   if ($.isEmptyObject(saveRequestTaskInfo)) {
     content = 'Not available';
+
+  } else if (saveRequestTaskInfo.note != null) {
+    content = `<pre>${saveRequestTaskInfo.note}</pre>`;
   } else {
     const saveRequestInfo = [];
     const taskData = {
