@@ -8,10 +8,11 @@ import json
 from typing import Dict
 
 from pygments.lexers import get_all_lexers, get_lexer_for_filename
-import sentry_sdk
 
 from django.contrib.staticfiles.finders import find
 
+from swh.web.common.exc import sentry_capture_exception
+
 
 @functools.lru_cache()
 def _hljs_languages_data():
@@ -140,7 +141,7 @@ def get_hljs_language_from_filename(filename):
         try:
             lexer = get_lexer_for_filename(filename)
         except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+            sentry_capture_exception(exc)
         # if there is a correspondence between the lexer and an hljs
         # language, return it
         if lexer and lexer.name in _pygments_lexer_to_hljs_language:
