@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2019  The Software Heritage developers
+# Copyright (C) 2015-2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,9 +10,8 @@ from corsheaders.middleware import (
     ACCESS_CONTROL_ALLOW_METHODS,
     ACCESS_CONTROL_ALLOW_ORIGIN,
 )
-from hypothesis import given
 
-from swh.model.identifiers import CONTENT, DIRECTORY, REVISION
+from swh.model.swhids import ObjectType
 from swh.web.api.apiresponse import (
     compute_link_header,
     filter_by_fields,
@@ -22,7 +21,6 @@ from swh.web.api.apiresponse import (
 from swh.web.common.identifiers import gen_swhid
 from swh.web.common.utils import reverse
 from swh.web.tests.django_asserts import assert_contains
-from swh.web.tests.strategies import content, directory, revision
 from swh.web.tests.utils import check_http_get_response, check_http_post_response
 
 
@@ -153,7 +151,6 @@ def test_error_response_handler(mocker, api_client):
     assert "Traceback" in resp.data["traceback"]
 
 
-@given(content(), directory(), revision())
 def test_api_endpoints_have_cors_headers(client, content, directory, revision):
     url = reverse("api-1-stat-counters")
 
@@ -163,9 +160,9 @@ def test_api_endpoints_have_cors_headers(client, content, directory, revision):
     assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
 
     swhids = [
-        gen_swhid(CONTENT, content["sha1_git"]),
-        gen_swhid(DIRECTORY, directory),
-        gen_swhid(REVISION, revision),
+        gen_swhid(ObjectType.CONTENT, content["sha1_git"]),
+        gen_swhid(ObjectType.DIRECTORY, directory),
+        gen_swhid(ObjectType.REVISION, revision),
     ]
     url = reverse("api-1-known")
     ac_request_method = "POST"
