@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2021  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -11,6 +11,7 @@ import pytest
 from django.core.exceptions import ObjectDoesNotExist
 from django.utils import timezone
 
+from swh.web.api.throttling import SwhWebUserRateThrottle
 from swh.web.auth.utils import API_SAVE_ORIGIN_PERMISSION, SWH_AMBASSADOR_PERMISSION
 from swh.web.common.models import (
     SAVE_REQUEST_ACCEPTED,
@@ -153,7 +154,10 @@ def check_save_request_status(
 def test_save_request_rejected(api_client, mocker, swh_scheduler):
     origin_url = "https://github.com/user/illegal_repo"
     check_created_save_request_status(
-        api_client, mocker, origin_url, expected_request_status=SAVE_REQUEST_REJECTED,
+        api_client,
+        mocker,
+        origin_url,
+        expected_request_status=SAVE_REQUEST_REJECTED,
     )
     check_save_request_status(
         api_client,
@@ -363,7 +367,7 @@ def test_save_requests_no_rate_limit_if_permission(
         url_args={"visit_type": _visit_type, "origin_url": _origin_url},
     )
 
-    for _ in range(save_origin_rate_post):
+    for _ in range(save_origin_rate_post * SwhWebUserRateThrottle.NUM_REQUESTS_FACTOR):
         check_api_post_response(api_client, url, status_code=200)
 
     check_api_post_response(api_client, url, status_code=200)
@@ -436,7 +440,10 @@ def test_create_save_request_pending_review_anonymous_user(
 
 
 def test_create_save_request_archives_with_ambassador_user(
-    api_client, keycloak_oidc, requests_mock, swh_scheduler,
+    api_client,
+    keycloak_oidc,
+    requests_mock,
+    swh_scheduler,
 ):
     swh_scheduler.add_load_archive_task_type()
 
@@ -454,12 +461,18 @@ def test_create_save_request_archives_with_ambassador_user(
     requests_mock.head(
         artifact_url,
         status_code=200,
-        headers={"content-length": content_length, "last-modified": last_modified,},
+        headers={
+            "content-length": content_length,
+            "last-modified": last_modified,
+        },
     )
 
     url = reverse(
         "api-1-save-origin",
-        url_args={"visit_type": "archives", "origin_url": originUrl,},
+        url_args={
+            "visit_type": "archives",
+            "origin_url": originUrl,
+        },
     )
 
     response = check_api_post_response(
@@ -468,7 +481,10 @@ def test_create_save_request_archives_with_ambassador_user(
         status_code=200,
         data={
             "archives_data": [
-                {"artifact_url": artifact_url, "artifact_version": artifact_version,}
+                {
+                    "artifact_url": artifact_url,
+                    "artifact_version": artifact_version,
+                }
             ]
         },
     )
@@ -492,10 +508,18 @@ def test_create_save_request_archives_missing_artifacts_data(
 
     url = reverse(
         "api-1-save-origin",
-        url_args={"visit_type": "archives", "origin_url": originUrl,},
+        url_args={
+            "visit_type": "archives",
+            "origin_url": originUrl,
+        },
     )
 
-    response = check_api_post_response(api_client, url, status_code=400, data={},)
+    response = check_api_post_response(
+        api_client,
+        url,
+        status_code=400,
+        data={},
+    )
     assert "Artifacts data are missing" in response.data["reason"]
 
     response = check_api_post_response(
@@ -529,7 +553,8 @@ def test_create_save_request_archives_accepted_ambassador_user(
 def test_create_save_request_anonymous_user_no_user_id(api_client, swh_scheduler):
     origin_url = "https://some.git.hosters/user/repo"
     url = reverse(
-        "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url},
+        "api-1-save-origin",
+        url_args={"visit_type": "git", "origin_url": origin_url},
     )
 
     check_api_post_responses(api_client, url, status_code=200)
@@ -547,7 +572,8 @@ def test_create_save_request_authenticated_user_id(
 
     origin_url = "https://some.git.hosters/user/repo2"
     url = reverse(
-        "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url},
+        "api-1-save-origin",
+        url_args={"visit_type": "git", "origin_url": origin_url},
     )
 
     response = check_api_post_response(api_client, url, status_code=200)
@@ -565,7 +591,8 @@ def test_create_pending_save_request_multiple_authenticated_users(
     origin_url = "https://some.git.hosters/user/repo3"
 
     url = reverse(
-        "api-1-save-origin", url_args={"visit_type": "git", "origin_url": origin_url},
+        "api-1-save-origin",
+        url_args={"visit_type": "git", "origin_url": origin_url},
     )
 
     api_client.force_login(regular_user)
