@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2021  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -31,12 +31,17 @@ from swh.model.hashutil import (
     hash_to_hex,
 )
 from swh.model.model import Content, Directory
-from swh.model.swhids import ObjectType
+from swh.model.swhids import CoreSWHID, ObjectType
 from swh.scheduler.tests.common import TASK_TYPES
 from swh.storage.algos.origin import origin_get_latest_visit_status
 from swh.storage.algos.revisions_walker import get_revisions_walker
 from swh.storage.algos.snapshot import snapshot_get_all_branches, snapshot_get_latest
-from swh.web.auth.utils import OIDC_SWH_WEB_CLIENT_ID
+from swh.web.auth.utils import (
+    ADD_FORGE_MODERATOR_PERMISSION,
+    MAILMAP_ADMIN_PERMISSION,
+    MAILMAP_PERMISSION,
+    OIDC_SWH_WEB_CLIENT_ID,
+)
 from swh.web.common import converters
 from swh.web.common.origin_save import get_scheduler_load_task_types
 from swh.web.common.typing import OriginVisitInfo
@@ -47,8 +52,12 @@ from swh.web.tests.data import (
     override_storages,
     random_content,
     random_sha1,
+    random_sha1_bytes,
     random_sha256,
 )
+from swh.web.tests.utils import create_django_permission
+
+os.environ["LC_ALL"] = "C.UTF-8"
 
 # Used to skip some tests
 ctags_json_missing = (
@@ -75,13 +84,19 @@ suppress_health_check = [
 
 
 settings.register_profile(
-    "swh-web", settings(deadline=None, suppress_health_check=suppress_health_check,),
+    "swh-web",
+    settings(
+        deadline=None,
+        suppress_health_check=suppress_health_check,
+    ),
 )
 
 settings.register_profile(
     "swh-web-fast",
     settings(
-        deadline=None, max_examples=5, suppress_health_check=suppress_health_check,
+        deadline=None,
+        max_examples=5,
+        suppress_health_check=suppress_health_check,
     ),
 )
 
@@ -221,22 +236,19 @@ def tests_data():
 
 @pytest.fixture(scope="function")
 def sha1():
-    """Fixture returning a valid hexadecimal sha1 value.
-    """
+    """Fixture returning a valid hexadecimal sha1 value."""
     return random_sha1()
 
 
 @pytest.fixture(scope="function")
 def invalid_sha1():
-    """Fixture returning an invalid sha1 representation.
-    """
+    """Fixture returning an invalid sha1 representation."""
     return hash_to_hex(bytes(random.randint(0, 255) for _ in range(50)))
 
 
 @pytest.fixture(scope="function")
 def sha256():
-    """Fixture returning a valid hexadecimal sha256 value.
-    """
+    """Fixture returning a valid hexadecimal sha256 value."""
     return random_sha256()
 
 
@@ -246,15 +258,13 @@ def _known_swh_objects(tests_data, object_type):
 
 @pytest.fixture(scope="function")
 def content(tests_data):
-    """Fixture returning a random content ingested into the test archive.
-    """
+    """Fixture returning a random content ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "contents"))
 
 
 @pytest.fixture(scope="function")
 def contents(tests_data):
-    """Fixture returning random contents ingested into the test archive.
-    """
+    """Fixture returning random contents ingested into the test archive."""
     return random.choices(
         _known_swh_objects(tests_data, "contents"), k=random.randint(2, 8)
     )
@@ -270,15 +280,13 @@ def _new_content(tests_data):
 
 @pytest.fixture(scope="function")
 def unknown_content(tests_data):
-    """Fixture returning a random content not ingested into the test archive.
-    """
+    """Fixture returning a random content not ingested into the test archive."""
     return _new_content(tests_data)
 
 
 @pytest.fixture(scope="function")
 def unknown_contents(tests_data):
-    """Fixture returning random contents not ingested into the test archive.
-    """
+    """Fixture returning random contents not ingested into the test archive."""
     new_contents = []
     new_content_ids = set()
     nb_contents = random.randint(2, 8)
@@ -292,8 +300,7 @@ def unknown_contents(tests_data):
 
 @pytest.fixture(scope="function")
 def empty_content():
-    """Fixture returning the empty content ingested into the test archive.
-    """
+    """Fixture returning the empty content ingested into the test archive."""
     empty_content = Content.from_data(data=b"").to_dict()
     for algo in DEFAULT_ALGORITHMS:
         empty_content[algo] = hash_to_hex(empty_content[algo])
@@ -388,8 +395,7 @@ def _content_image_type():
 
 @pytest.fixture(scope="function")
 def content_image_type():
-    """Fixture returning a random image content ingested into the test archive.
-    """
+    """Fixture returning a random image content ingested into the test archive."""
     return random.choice(_content_image_type())
 
 
@@ -469,8 +475,7 @@ def contents_with_ctags():
 
 @pytest.fixture(scope="function")
 def directory(tests_data):
-    """Fixture returning a random directory ingested into the test archive.
-    """
+    """Fixture returning a random directory ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "directories"))
 
 
@@ -500,15 +505,13 @@ def directory_with_subdirs():
 
 @pytest.fixture(scope="function")
 def directory_with_files():
-    """Fixture returning a random directory containing at least one regular file.
-    """
+    """Fixture returning a random directory containing at least one regular file."""
     return random.choice(_directory_with_entry_type("file"))
 
 
 @pytest.fixture(scope="function")
 def unknown_directory(tests_data):
-    """Fixture returning a random directory not ingested into the test archive.
-    """
+    """Fixture returning a random directory not ingested into the test archive."""
     while True:
         new_directory = random_sha1()
         sha1_bytes = hash_to_bytes(new_directory)
@@ -518,42 +521,41 @@ def unknown_directory(tests_data):
 
 @pytest.fixture(scope="function")
 def empty_directory():
-    """Fixture returning the empty directory ingested into the test archive.
-    """
+    """Fixture returning the empty directory ingested into the test archive."""
     return Directory(entries=()).id.hex()
 
 
 @pytest.fixture(scope="function")
 def revision(tests_data):
-    """Fixturereturning a random revision ingested into the test archive.
-    """
+    """Fixturereturning a random revision ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "revisions"))
 
 
 @pytest.fixture(scope="function")
 def revisions(tests_data):
-    """Fixture returning random revisions ingested into the test archive.
-    """
+    """Fixture returning random revisions ingested into the test archive."""
     return random.choices(
-        _known_swh_objects(tests_data, "revisions"), k=random.randint(2, 8),
+        _known_swh_objects(tests_data, "revisions"),
+        k=random.randint(2, 8),
     )
 
 
 @pytest.fixture(scope="function")
 def revisions_list(tests_data):
-    """Fixture returning random revisions ingested into the test archive.
-    """
+    """Fixture returning random revisions ingested into the test archive."""
 
     def gen_revisions_list(size):
-        return random.choices(_known_swh_objects(tests_data, "revisions"), k=size,)
+        return random.choices(
+            _known_swh_objects(tests_data, "revisions"),
+            k=size,
+        )
 
     return gen_revisions_list
 
 
 @pytest.fixture(scope="function")
 def unknown_revision(tests_data):
-    """Fixture returning a random revision not ingested into the test archive.
-    """
+    """Fixture returning a random revision not ingested into the test archive."""
     while True:
         new_revision = random_sha1()
         sha1_bytes = hash_to_bytes(new_revision)
@@ -663,15 +665,13 @@ def revision_with_submodules():
 
 @pytest.fixture(scope="function")
 def release(tests_data):
-    """Fixture returning a random release ingested into the test archive.
-    """
+    """Fixture returning a random release ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "releases"))
 
 
 @pytest.fixture(scope="function")
 def releases(tests_data):
-    """Fixture returning random releases ingested into the test archive.
-    """
+    """Fixture returning random releases ingested into the test archive."""
     return random.choices(
         _known_swh_objects(tests_data, "releases"), k=random.randint(2, 8)
     )
@@ -679,8 +679,7 @@ def releases(tests_data):
 
 @pytest.fixture(scope="function")
 def unknown_release(tests_data):
-    """Fixture returning a random release not ingested into the test archive.
-    """
+    """Fixture returning a random release not ingested into the test archive."""
     while True:
         new_release = random_sha1()
         sha1_bytes = hash_to_bytes(new_release)
@@ -690,15 +689,13 @@ def unknown_release(tests_data):
 
 @pytest.fixture(scope="function")
 def snapshot(tests_data):
-    """Fixture returning a random snapshot ingested into the test archive.
-    """
+    """Fixture returning a random snapshot ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "snapshots"))
 
 
 @pytest.fixture(scope="function")
 def unknown_snapshot(tests_data):
-    """Fixture returning a random snapshot not ingested into the test archive.
-    """
+    """Fixture returning a random snapshot not ingested into the test archive."""
     while True:
         new_snapshot = random_sha1()
         sha1_bytes = hash_to_bytes(new_snapshot)
@@ -708,8 +705,7 @@ def unknown_snapshot(tests_data):
 
 @pytest.fixture(scope="function")
 def origin(tests_data):
-    """Fixture returning a random origin ingested into the test archive.
-    """
+    """Fixture returning a random origin ingested into the test archive."""
     return random.choice(_known_swh_objects(tests_data, "origins"))
 
 
@@ -746,8 +742,7 @@ def _origin_with_releases():
 
 @pytest.fixture(scope="function")
 def origin_with_releases():
-    """Fixture returning a random origin with releases ingested into the test archive.
-    """
+    """Fixture returning a random origin with releases ingested into the test archive."""
     return random.choice(_origin_with_releases())
 
 
@@ -821,6 +816,18 @@ def snapshot_swhid():
     return random.choice(_object_type_swhid(ObjectType.SNAPSHOT))
 
 
+@pytest.fixture(scope="function", params=list(ObjectType))
+def unknown_core_swhid(request) -> CoreSWHID:
+    """Fixture returning an unknown core SWHID.
+
+    Tests using this will be called once per object type.
+    """
+    return CoreSWHID(
+        object_type=request.param,
+        object_id=random_sha1_bytes(),
+    )
+
+
 # Fixture to manipulate data from a sample archive used in the tests
 @pytest.fixture(scope="function")
 def archive_data(tests_data):
@@ -1109,6 +1116,8 @@ def swh_scheduler(swh_scheduler):
     config["scheduler"] = swh_scheduler
     # create load-git and load-hg task types
     for task_type in TASK_TYPES.values():
+        # see https://forge.softwareheritage.org/rDSCHc46ffadf7adf24c7eb3ffce062e8ade3818c79cc  # noqa
+        task_type["type"] = task_type["type"].replace("load-test-", "load-", 1)
         swh_scheduler.create_task_type(task_type)
     # create load-svn task type
     swh_scheduler.create_task_type(
@@ -1140,6 +1149,21 @@ def swh_scheduler(swh_scheduler):
             "retry_delay": timedelta(hours=2),
         }
     )
+    # create load-bzr task type
+    swh_scheduler.create_task_type(
+        {
+            "type": "load-bzr",
+            "description": "Update a Bazaar repository",
+            "backend_name": "swh.loader.bzr.tasks.LoadBazaar",
+            "default_interval": timedelta(days=64),
+            "min_interval": timedelta(hours=12),
+            "max_interval": timedelta(days=64),
+            "backoff_factor": 2,
+            "max_queue_length": None,
+            "num_retries": 7,
+            "retry_delay": timedelta(hours=2),
+        }
+    )
 
     # add method to add load-archive-files task type during tests
     def add_load_archive_task_type():
@@ -1197,3 +1221,28 @@ def regular_user():
 @pytest.fixture
 def regular_user2():
     return User.objects.create_user(username="janedoe", password="")
+
+
+@pytest.fixture
+def add_forge_moderator():
+    moderator = User.objects.create_user(username="add-forge moderator", password="")
+    moderator.user_permissions.add(
+        create_django_permission(ADD_FORGE_MODERATOR_PERMISSION)
+    )
+    return moderator
+
+
+@pytest.fixture
+def mailmap_admin():
+    mailmap_admin = User.objects.create_user(username="mailmap-admin", password="")
+    mailmap_admin.user_permissions.add(
+        create_django_permission(MAILMAP_ADMIN_PERMISSION)
+    )
+    return mailmap_admin
+
+
+@pytest.fixture
+def mailmap_user():
+    mailmap_user = User.objects.create_user(username="mailmap-user", password="")
+    mailmap_user.user_permissions.add(create_django_permission(MAILMAP_PERMISSION))
+    return mailmap_user
